@@ -4,7 +4,7 @@
 ;;
 ;; Author: Thomas Wimmer <thomaswimmer@posteo.com>
 ;; URL: https://github.com/twmr/gerrit.el
-;; Package-Requires: ((emacs "25.1") (magit "2.13.1"))
+;; Package-Requires: ((emacs "26.1") (magit "2.13.1"))
 
 ;; This file is not part of GNU Emacs.
 
@@ -34,13 +34,18 @@
 (require 'json)
 (require 'cl-lib)
 (require 'cl-extra) ;; for cl-prettyprint
+(require 'url)
+(require 'url-auth)
+(require 'url-http)
 
 (defvar gerrit-host) ;; defined in gerrit.el
 (declare-function gerrit--get-protocol "gerrit.el")
 (defvar gerrit-patch-buffer)
+
 (defvar url-http-end-of-headers)
 (defvar url-http-response-status)
 
+
 (defcustom gerrit-rest-endpoint-prefix "/a"
   "String that is appended to `gerrit-host'.
 For newer gerrit servers this needs to be set to /a, whereas on older
@@ -106,8 +111,8 @@ The optional arg DATA may be used as inputs for POST/PUT requests."
                           (concat "?" (url-build-query-string params))))))
 
     (when data
-      (add-to-list 'url-request-extra-headers
-                   '("Content-Type" . "application/json")))
+      (push '("Content-Type" . "application/json")
+            url-request-extra-headers))
 
     (with-current-buffer (url-retrieve-synchronously target t)
       ;; I need to skip the read-json code when there is nothing to parse in the output
